'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// 1xx
const INFORMATIONAL = {
    '100': 'Continue',
    '101': 'Switching Protocols',
    '102': 'Processing',
};
// 2xx
const SUCCESS = {
    '200': 'OK',
    '201': 'Created',
    '202': 'Accepted',
    '203': 'Non-authoritative Information',
    '204': 'No Content',
    '205': 'Reset Content',
    '206': 'Partial Content',
    '207': 'Multi-Status',
    '208': 'Already Reported',
    '209': 'IM Used',
};
// 3xx
const REDIRECTION = {
    '300': 'Multiple Choices',
    '301': 'Moved Permanently',
    '302': 'Found',
    '303': 'See Other',
    '304': 'Not Modified',
    '305': 'Use Proxy',
    '307': 'Temporary Redirect',
    '308': 'Permanent Redirect',
};
// 4xx
const CLIENT_ERROR = {
    '400': 'Bad Request',
    '401': 'Unauthorized',
    '402': 'Payment Required',
    '403': 'Forbidden',
    '404': 'Not Found',
    '405': 'Method Not Allowed',
    '406': 'Not Acceptable',
    '407': 'Proxy Authentication Required',
    '408': 'Request Timeout',
    '409': 'Conflict',
    '410': 'Gone',
    '411': 'Length Required',
    '412': 'Precondition Failed',
    '413': 'Payload Too Large',
    '414': 'Request-URI Too Long',
    '415': 'Unsupported Media Type',
    '416': 'Requested Range Not Satisfiable',
    '417': 'Expectation Failed',
    '418': "I'm a teapot",
    '421': 'Misdirected Request',
    '422': 'Unprocessable Entity',
    '423': 'Locked',
    '424': 'Failed Dependency',
    '426': 'Upgrade Required',
    '428': 'Precondition Required',
    '429': 'Too Many Requests',
    '431': 'Request Header Fields Too Large',
    '444': 'Connection Closed Without Response',
    '451': 'Unavailable For Legal Reasons',
    '499': 'Client Closed Request',
};
// 4xx
const SERVER_ERROR = {
    '500': 'Internal Server Error',
    '501': 'Not Implemented',
    '502': 'Bad Gateway',
    '503': 'Service Unavailable',
    '504': 'Gateway Timeout',
    '505': 'HTTP Version Not Supported',
    '506': 'Variant Also Negotiates',
    '507': 'Insufficient Storage',
    '508': 'Loop Detected',
    '510': 'Not Extended',
    '511': 'Network Authentication Required',
    '599': 'Network Connect Timeout Error',
};

const makeErrorModel = ({ code }) => {
    var _code = Number(code);
    var _title = SERVER_ERROR[500];
    if (_code >= 400 && _code < 500) {
        _title = CLIENT_ERROR[code];
    }
    else {
        _title = SERVER_ERROR[code];
    }
    return { title: _title, status: _code };
};
const makeError = ({ code, message, data }) => {
    throw Object.assign(makeErrorModel({ code }), { message, data });
};

const makeResponseModel = ({ code }) => {
    var _title = SUCCESS[200];
    var _code = Number(code);
    if (_code >= 100 && _code < 200) {
        _title = INFORMATIONAL[code];
    }
    else if (_code >= 200 && _code < 300) {
        _title = SUCCESS[code];
    }
    else {
        _title = REDIRECTION[code];
    }
    return { title: _title, status: _code };
};
const makeResponse = ({ code, message, data }) => {
    return Object.assign(makeResponseModel({ code }), { message, data });
};

exports.makeError = makeError;
exports.makeResponse = makeResponse;
//# sourceMappingURL=index.js.map
